@@ -39,22 +39,21 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #endif
 
 #include "../pix_version.h"
-#include <MauiKit/FileBrowsing/fmstatic.h>
+
 #include <MauiKit/Core/mauiapp.h>
+#include <MauiKit/FileBrowsing/fmstatic.h>
 
 #ifdef Q_OS_MACOS
-#include "mauimacos.h"
+#include <MauiKit/Core/mauimacos.h>
 #endif
 
-#if defined Q_OS_MACOS || defined Q_OS_WIN
-#include <KF5/KI18n/KLocalizedString>
-#else
 #include <KI18n/KLocalizedString>
-#endif
 
 #include "models/folders/folders.h"
 #include "models/gallery/gallery.h"
 #include "models/tags/tagsmodel.h"
+#include "models/cities/citiesmodel.h"
+
 #include "pix.h"
 
 #define PIX_URI "org.maui.pix"
@@ -94,9 +93,7 @@ static const QList<QUrl> openFiles(const QStringList &files)
 Q_DECL_EXPORT int main(int argc, char *argv[])
 {
     QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
-    QCoreApplication::setAttribute(Qt::AA_DontCreateNativeWidgetSiblings);
     QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-    QCoreApplication::setAttribute(Qt::AA_DisableSessionManager, true);
 
 #ifdef Q_OS_ANDROID
     QGuiApplication app(argc, argv);
@@ -109,11 +106,10 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     app.setOrganizationName(QStringLiteral("Maui"));
     app.setWindowIcon(QIcon(":/assets/pix.png"));
 
-    MauiApp::instance()->setHandleAccounts(false); // for now pix can not handle cloud accounts
     MauiApp::instance()->setIconName("qrc:/assets/pix.svg");
 
     KLocalizedString::setApplicationDomain("pix");
-    KAboutData about(QStringLiteral("pix"), i18n("Pix"), PIX_VERSION_STRING, i18n("Pix lets you organize, browse, and edit your image collection."), KAboutLicense::LGPL_V3, i18n("© 2019-%1 Nitrux Development Team", QString::number(QDate::currentDate().year())), QString(GIT_BRANCH) + "/" + QString(GIT_COMMIT_HASH));
+    KAboutData about(QStringLiteral("pix"), i18n("Pix"), PIX_VERSION_STRING, i18n("Organize, browse, and edit your images."), KAboutLicense::LGPL_V3, i18n("© 2019-%1 Maui Development Team", QString::number(QDate::currentDate().year())), QString(GIT_BRANCH) + "/" + QString(GIT_COMMIT_HASH));
     about.addAuthor(i18n("Camilo Higuita"), i18n("Developer"), QStringLiteral("milo.h@aol.com"));
     about.setHomepage("https://mauikit.org");
     about.setProductName("maui/pix");
@@ -124,9 +120,10 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
     KAboutData::setApplicationData(about);
 
     QCommandLineParser parser;
-    parser.process(app);
 
     about.setupCommandLine(&parser);
+    parser.process(app);
+
     about.processCommandLine(&parser);
 
     const QStringList args = parser.positionalArguments();
@@ -145,6 +142,7 @@ Q_DECL_EXPORT int main(int argc, char *argv[])
 
     qmlRegisterType<Gallery>(PIX_URI, 1, 0, "GalleryList");
     qmlRegisterType<Folders>(PIX_URI, 1, 0, "FoldersList");
+    qmlRegisterType<CitiesModel>(PIX_URI, 1, 0, "CitiesList");
     qmlRegisterType<TagsModel>(PIX_URI, 1, 0, "TagsList");
 
     engine.load(QUrl(QStringLiteral("qrc:/main.qml")));
