@@ -6,9 +6,7 @@
 
 Folders::Folders(QObject *parent)
     : MauiList(parent)
-{
-    qDebug() << "CREATING GALLERY LIST";
-}
+{}
 
 const FMH::MODEL_LIST &Folders::items() const
 {
@@ -21,15 +19,7 @@ void Folders::setFolders(const QList<QUrl> &folders)
         return;
 
     m_folders = folders;
-
-    emit this->preListChanged();
-    this->list.clear();
-
-    for (const auto &folder : m_folders) {
-        this->list << FMStatic::getDirInfoModel(folder);
-    }
-    emit this->postListChanged();
-    emit foldersChanged();
+    emit this->foldersChanged();
 }
 
 QList<QUrl> Folders::folders() const
@@ -37,14 +27,29 @@ QList<QUrl> Folders::folders() const
     return m_folders;
 }
 
-QVariantMap Folders::get(const int &index) const
-{
-    if (index >= this->list.size() || index < 0)
-        return QVariantMap();
-    return FMH::toMap(this->list.at(this->mappedIndex(index)));
-}
-
 void Folders::refresh()
 {
     this->setFolders(m_folders);
 }
+
+void Folders::componentComplete()
+{
+    connect (this, &Folders::foldersChanged, this, &Folders::setList);
+    setList();
+}
+
+void Folders::setList()
+{
+    emit this->preListChanged();
+    this->list.clear();
+
+    for (const auto &folder : std::as_const(m_folders))
+    {
+        this->list << FMStatic::getFileInfoModel(folder);
+    }
+
+    emit this->postListChanged();
+    emit this->countChanged();
+}
+
+
