@@ -5,12 +5,13 @@
 
 
 .import org.mauikit.filebrowsing 1.2 as FB
+.import QtQuick.Controls 2.15 as QQC2
 
 function open(model, index)
 {
     _pixViewer.model = model
     _pixViewer.view(index)
-    _stackView.push(_pixViewer)
+    _stackView.push(_pixViewer, QQC2.StackView.ReplaceTransition)
 }
 
 function openExternalPics(pics, index)
